@@ -1,6 +1,7 @@
 """
-redflag
+Core functions
 
 Author: Matt Hall, agilescientific.com
 Licence: Apache 2.0
 """
+pass
\ No newline at end of file
